[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

# Introduction 
This repo tracks the evidi_fabric package which is intended to collect useful helper when working with fabric.

## Installation
```bash
pip install evidi_fabric
```
More details are availble on the wiki regarding [How to contribute](./.wiki/how-to-contribute.md), [Initial Setup](./.wiki/initial-setup.md) and on [How To Use it](./.wiki/how-to-use.md). 

